@@ -64,10 +64,15 @@ class S3Storage(Storage):
             # bytes storage used to store S3's object key
             binary_obj = Binary(key.encode())
             entity.cw_edited.edited_attribute(attr, binary_obj)
+            # required workaround for boto3 bug
+            # https://github.com/boto/s3transfer/issues/80
+            # .read() is required since Binary can't wrap itself
+            buffer = Binary(binary.read())
             self.debug('Upload object to S3')
             # upload_fileobj should make automagically a multipart upload if
             # needed
-            self.s3cnx.upload_fileobj(binary, self.bucket, key)
+            self.s3cnx.upload_fileobj(buffer, self.bucket, key)
+            buffer.close()
             self.info('Uploaded object %s.%s to S3', entity.eid, attr)
         return binary
 
